@@ -65,9 +65,28 @@ Puppet::Type.type(:glance_image).provide(
     opts << "--tag=#{@resource[:image_tag]}" if @resource[:image_tag]
     opts << location
 
+    if @resource[:project_name]
+      opts << "--project=#{@resource[:project_name]}"
+    elsif @resource[:project_id]
+      opts << "--project=#{@resource[:project_id]}"
+    end
+
     begin
-      @property_hash = self.class.request('image', 'create', opts)
-      @property_hash[:ensure] = :present
+      attrs = self.class.request('image', 'create', opts)
+      properties = self.class.parsestring(attrs[:properties]) rescue nil
+      @property_hash = {
+        :ensure           => :present,
+        :name             => attrs[:name],
+        :is_public        => attrs[:visibility].downcase.chomp == 'public'? true : false,
+        :container_format => attrs[:container_format],
+        :id               => attrs[:id],
+        :disk_format      => attrs[:disk_format],
+        :min_disk         => attrs[:min_disk],
+        :min_ram          => attrs[:min_ram],
+        :properties       => self.class.exclude_owner_specified_props(self.class.exclude_readonly_props(properties)),
+        :image_tag        => attrs[:tags],
+        :project_id       => attrs[:owner]
+      }
     ensure
       if temp_file
         temp_file.close(true)
@@ -86,36 +105,24 @@ Puppet::Type.type(:glance_image).provide(
 
   mk_resource_methods
 
-  def is_public=(value)
-    @property_flush[:is_public] = value
-  end
-
   def is_public
     bool_to_sym(@property_hash[:is_public])
   end
 
-  def disk_format=(value)
-    @property_flush[:disk_format] = value
-  end
-
-  def container_format=(value)
-    @property_flush[:container_format] = value
-  end
-
-  def min_ram=(value)
-    @property_flush[:min_ram] = value
-  end
-
-  def min_disk=(value)
-    @property_flush[:min_disk] = value
-  end
-
-  def properties=(value)
-    @property_flush[:properties] = value
-  end
-
-  def image_tag=(value)
-    @property_flush[:image_tag] = value
+  [
+    :is_public,
+    :disk_format,
+    :container_format,
+    :min_ram,
+    :min_disk,
+    :properties,
+    :image_tag,
+    :project_id,
+    :project_name
+  ].each do |attr|
+    define_method(attr.to_s + "=") do |value|
+      @property_flush[attr] = value
+    end
   end
 
   def id=(id)
@@ -137,7 +144,8 @@ Puppet::Type.type(:glance_image).provide(
         :min_disk         => attrs[:min_disk],
         :min_ram          => attrs[:min_ram],
         :properties       => exclude_owner_specified_props(exclude_readonly_props(properties)),
-        :image_tag        => attrs[:image_tag]
+        :image_tag        => attrs[:tags],
+        :project_id       => attrs[:owner]
       )
     end
   end
@@ -164,6 +172,12 @@ Puppet::Type.type(:glance_image).provide(
       (opts << props_to_s(@property_flush[:properties])) if @property_flush[:properties]
       (opts << "--tag=#{@property_flush[:image_tag]}") if @property_flush[:image_tag]
 
+      if @property_flush[:project_name]
+        opts << "--project=#{@property_flush[:project_name]}"
+      elsif @property_flush[:project_id]
+        opts << "--project=#{@property_flush[:project_id]}"
+      end
+
       self.class.request('image', 'set', opts)
       @property_flush.clear
     end
