@@ -22,8 +22,8 @@ describe 'glance::api' do
       :location_strategy              => '<SERVICE DEFAULT>',
       :purge_config                   => false,
       :delayed_delete                 => '<SERVICE DEFAULT>',
-      :scrub_time                     => '<SERVICE DEFAULT>',
       :enforce_secure_rbac            => '<SERVICE DEFAULT>',
+      :use_keystone_limits            => '<SERVICE DEFAULT>',
       :image_cache_dir                => '/var/lib/glance/image-cache',
       :image_import_plugins           => '<SERVICE DEFAULT>',
       :image_conversion_output_format => '<SERVICE DEFAULT>',
@@ -33,6 +33,11 @@ describe 'glance::api' do
       :node_staging_uri               => '<SERVICE DEFAULT>',
       :worker_self_reference_url      => '<SERVICE DEFAULT>',
       :image_member_quota             => '<SERVICE DEFAULT>',
+      :image_property_quota           => '<SERVICE DEFAULT>',
+      :image_tag_quota                => '<SERVICE DEFAULT>',
+      :image_location_quota           => '<SERVICE DEFAULT>',
+      :image_size_cap                 => '<SERVICE DEFAULT>',
+      :user_storage_quota             => '<SERVICE DEFAULT>',
       :image_cache_stall_time         => '<SERVICE DEFAULT>',
       :image_cache_max_size           => '<SERVICE DEFAULT>',
       :cache_prefetcher_interval      => '<SERVICE DEFAULT>',
@@ -65,8 +70,8 @@ describe 'glance::api' do
         :filesystem_store_file_perm     => '0644',
         :location_strategy              => 'store_type',
         :delayed_delete                 => 'true',
-        :scrub_time                     => '10',
         :enforce_secure_rbac            => 'true',
+        :use_keystone_limits            => 'true',
         :image_cache_dir                => '/tmp/glance',
         :image_import_plugins           => 'image_conversion',
         :image_conversion_output_format => 'raw',
@@ -75,7 +80,12 @@ describe 'glance::api' do
         :enabled_import_methods         => 'glance-direct,web-download',
         :node_staging_uri               => '/tmp/staging',
         :worker_self_reference_url      => 'http://worker1',
-        :image_member_quota             => '128',
+        :image_member_quota             => 128,
+        :image_property_quota           => 129,
+        :image_tag_quota                => 130,
+        :image_location_quota           => 10,
+        :image_size_cap                 => 1099511627776,
+        :user_storage_quota             => 0,
         :image_cache_stall_time         => '10',
         :image_cache_max_size           => '10737418240',
         :cache_prefetcher_interval      => '300',
@@ -115,7 +125,6 @@ describe 'glance::api' do
           'tag'        => 'glance-service',
         ) }
 
-        it { is_expected.to_not contain_exec('validate_nova_api') }
         it { is_expected.to contain_glance_api_config("paste_deploy/flavor").with_value(param_hash[:pipeline]) }
 
         it 'is_expected.to lay down default api config' do
@@ -126,8 +135,8 @@ describe 'glance::api' do
             'show_multiple_locations',
             'location_strategy',
             'delayed_delete',
-            'scrub_time',
             'enforce_secure_rbac',
+            'use_keystone_limits',
             'image_cache_dir',
             'image_cache_stall_time',
             'image_cache_max_size',
@@ -135,6 +144,11 @@ describe 'glance::api' do
             'node_staging_uri',
             'worker_self_reference_url',
             'image_member_quota',
+            'image_property_quota',
+            'image_tag_quota',
+            'image_location_quota',
+            'image_size_cap',
+            'user_storage_quota',
             'limit_param_default',
             'api_limit_max',
           ].each do |config|
@@ -189,12 +203,6 @@ describe 'glance::api' do
           is_expected.to contain_glance_api_config('taskflow_executor/conversion_format').with_value(param_hash[:conversion_format])
         end
 
-        it 'is_expected.to have no ssl options' do
-          is_expected.to contain_glance_api_config('DEFAULT/ca_file').with_value('<SERVICE DEFAULT>')
-          is_expected.to contain_glance_api_config('DEFAULT/cert_file').with_value('<SERVICE DEFAULT>')
-          is_expected.to contain_glance_api_config('DEFAULT/key_file').with_value('<SERVICE DEFAULT>')
-        end
-
         it 'is_expected.to have no formats set' do
           is_expected.to contain_glance_api_config('image_format/container_formats').with_value('<SERVICE DEFAULT>')
           is_expected.to contain_glance_api_config('image_format/disk_formats').with_value('<SERVICE DEFAULT>')
@@ -217,13 +225,7 @@ describe 'glance::api' do
         }
       end
 
-      it { is_expected.to contain_service('glance-api').with(
-          'ensure'     => nil,
-          'enable'     => false,
-          'hasstatus'  => true,
-          'hasrestart' => true,
-          'tag'        => 'glance-service',
-        ) }
+      it { is_expected.to_not contain_service('glance-api') }
     end
 
     describe 'with overridden pipeline' do
@@ -285,22 +287,6 @@ describe 'glance::api' do
       )}
     end
 
-    describe 'with ssl options' do
-      let :params do
-        default_params.merge({
-          :ca_file                   => '/tmp/ca_file',
-          :cert_file                 => '/tmp/cert_file',
-          :key_file                  => '/tmp/key_file',
-        })
-      end
-
-      context 'with ssl options' do
-        it { is_expected.to contain_glance_api_config('DEFAULT/ca_file').with_value('/tmp/ca_file') }
-        it { is_expected.to contain_glance_api_config('DEFAULT/cert_file').with_value('/tmp/cert_file') }
-        it { is_expected.to contain_glance_api_config('DEFAULT/key_file').with_value('/tmp/key_file') }
-      end
-    end
-
     describe 'with formats options with strings' do
       let :params do
         default_params.merge({
@@ -468,33 +454,6 @@ describe 'glance::api' do
       end
     end
 
-    describe 'while validating the service with default command' do
-      let :params do
-        default_params.merge({
-          :validate => true,
-        })
-      end
-      it { is_expected.to contain_openstacklib__service_validation('glance-api').with(
-        :command   => 'glance --os-auth-url http://127.0.0.1:5000 --os-project-name services --os-username glance --os-password ChangeMe image-list',
-        :subscribe => 'Service[glance-api]',
-      )}
-
-    end
-
-    describe 'while validating the service with custom command' do
-      let :params do
-        default_params.merge({
-          :validate            => true,
-          :validation_options  => { 'glance-api' => { 'command' => 'my-script' } }
-        })
-      end
-      it { is_expected.to contain_openstacklib__service_validation('glance-api').with(
-        :command   => 'my-script',
-        :subscribe => 'Service[glance-api]',
-      )}
-
-    end
-
     describe 'with barbican parameters' do
       let :params do
         default_params.merge!({
@@ -511,7 +470,7 @@ describe 'glance::api' do
     end
   end
 
-  shared_examples_for 'glance::api Debian' do
+  shared_examples_for 'glance::api on Debian' do
     let(:params) { default_params }
 
     # We only test this on Debian platforms, since on RedHat there isn't a
@@ -520,21 +479,13 @@ describe 'glance::api' do
       context "with package_ensure '#{package_ensure}'" do
         let(:params) { default_params.merge({ :package_ensure => package_ensure }) }
         it { is_expected.to contain_package('glance-api').with(
-            :ensure => package_ensure,
-            :tag    => ['openstack', 'glance-package']
+          :ensure => package_ensure,
+          :tag    => ['openstack', 'glance-package']
         )}
       end
     end
   end
 
-  shared_examples_for 'glance::api RedHat' do
-    let(:params) { default_params }
-
-    it { is_expected.to contain_package('openstack-glance').with(
-        :tag => ['openstack', 'glance-package'],
-    )}
-  end
-
   on_supported_os({
     :supported_os   => OSDefaults.get_supported_os
   }).each do |os,facts|
@@ -544,17 +495,9 @@ describe 'glance::api' do
       end
 
       it_configures 'glance::api'
-      it_configures "glance::api #{facts[:osfamily]}"
+      if facts[:osfamily] == 'Debian'
+        it_configures "glance::api on #{facts[:osfamily]}"
+      end
     end
   end
-
-  describe 'on unknown platforms' do
-    let :facts do
-      OSDefaults.get_facts({ :osfamily => 'unknown', :os => { :family => 'unknown', :release => { :major => '1'}}})
-    end
-    let(:params) { default_params }
-
-    it_raises 'a Puppet::Error', /module glance only support osfamily RedHat and Debian/
-  end
-
 end
